#
# spec file for package python-pygal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pygal
Version:        3.0.4
Release:        1.4
Summary:        A python svg graph plotting library
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            http://pygal.org/
Source:         https://files.pythonhosted.org/packages/source/p/pygal/pygal-%{version}.tar.gz
BuildRequires:  %{python_module CairoSVG}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pyquery}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata
Requires:       python-lxml
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-CairoSVG
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Pygal is a dynamic SVG charting library written in python.
It supports various chart types and CSS styling.

%prep
%autosetup -p1 -n pygal-%{version}

# not sure where to report
sed -Ei 's:.pytest-runner.,?::' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mv %{buildroot}%{_bindir}/pygal_gen.py %{buildroot}%{_bindir}/pygal_gen
%python_clone -a %{buildroot}%{_bindir}/pygal_gen

%check
%pytest

%post
%python_install_alternative pygal_gen

%postun
%python_uninstall_alternative pygal_gen

%files %{python_files}
%doc README
%license COPYING
%python_alternative %{_bindir}/pygal_gen
%{python_sitelib}/*

%changelog
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.4:
  * Missing declaration of importlib_metadata dependency in setup.py
  * Failure with tox due to missing README.md
  * Misused entry_points causing failure with Python 3.12
  * Prevent installing with Python versions < 3.8
  * Replace unmaintained pytest-flake8 with plain flake8
  * Remove Iterable import deprecation warning
  * Remove invalid escape sequence warnings in tests
  * Fix test failures due to removed pytest attribute
  * Fix linting errors with latest isort and flake8
- use packaged COPYING
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Feb  1 2023 Dirk Müller <dmueller@suse.com>
- skip python 2.x (no longer supported) and enable CairoSVG
  for all python flavors not just the main one
* Thu Dec  9 2021 Matej Cepl <mcepl@suse.com>
- Remove unnecessary patches: pytest4.patch, pytest6.patch, and
  python38.patch.
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 3.0.0
  * no upstream changelog found
* Mon Feb 22 2021 Markéta Machová <mmachova@suse.com>
- Drop broken %%ifpython3
* Thu Aug 27 2020 Marketa Calabkova <mcalabkova@suse.com>
- Add patch pytest6.patch
* Wed Nov  6 2019 Matej Cepl <mcepl@suse.com>
- Add patch pytest4.patch to make the test suite compatible with
  pytest4+ (yes, THIS is the only change necessary!).
  gh#Kozea/pygal#340
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with python 3.8:
  * python38.patch
- Restrict pytest to < 3.0 as the testing code does not work
  upstream on anything else
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make CairoSVG only python3 dependency and simply not provide
  the png conversion feature on python2
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
- dependencies are python3-only
* Mon Aug 28 2017 toddrme2178@gmail.com
- Implement single-spec version
* Sat Jul 29 2017 michael@stroeder.com
- update to upstream release 2.4.0
* Fri Jun 12 2015 mailaender@opensuse.org
- initial packaging of version 1.7.0
